@@ -21,6 +21,7 @@ import _socket
 import json
 
 import ntplib
+
 import gevent
 from gevent import Greenlet
 from gevent.server import StreamServer
@@ -59,6 +60,11 @@ class Honeypot(object):
         self.config = config
         self.key = key
         self.cert = cert
+        self._servers = []
+        self._server_greenlets = []
+        # will contain Session objects
+        self._sessions = {}
+        self._session_consumer = None
 
         # TODO: pass honeypot otherwise
         Session.honeypot_id = self.config['general']['id']
@@ -110,23 +116,23 @@ class Honeypot(object):
         ntp_poll = self.config['timecheck']['ntp_pool']
         while True:
             clnt = ntplib.NTPClient()
-            response = clnt.request(ntp_poll, version=3)
-            diff = response.offset
-            if abs(diff) >= 5:
-                logger.error('Timings found to be far off. ({0})'.format(diff))
-                sys.exit(1)
+            try:
+                response = clnt.request(ntp_poll, version=3)
+                diff = response.offset
+                if abs(diff) >= 15:
+                    logger.error('Timings found to be far off, shutting down drone ({0})'.format(diff))
+                    sys.exit(1)
+                else:
+                    logger.debug('Polled ntp server and found that drone has {0} seconds offset.'.format(diff))
+            except (ntplib.NTPException, _socket.error) as ex:
+                logger.warning('Error while polling ntp server: {0}'.format(ex))
             gevent.sleep(poll * 60 * 60)
 
     def start(self):
         """ Starts services. """
-        self.servers = []
-        self.server_greenlets = []
-        # will contain Session objects
-        self.sessions = {}
-
         # greenlet to consume the provided sessions
-        self.session_consumer = Consumer(self.sessions, self.honeypot_ip, self.config)
-        Greenlet.spawn(self.session_consumer.start)
+        self._session_consumer = Consumer(self._sessions, self.honeypot_ip, self.config)
+        Greenlet.spawn(self._session_consumer.start)
 
         # protocol handlers
         for c in handlerbase.HandlerBase.__subclasses__():
@@ -137,7 +143,7 @@ class Honeypot(object):
                 port = self.config['capabilities'][cap_name]['port']
                 # carve out the options for this specific service
                 options = self.config['capabilities'][cap_name]
-                cap = c(self.sessions, options, self.work_dir)
+                cap = c(self._sessions, options, self.work_dir)
 
                 try:
                     # Convention: All capability names which end in 's' will be wrapped in ssl.
@@ -148,9 +154,9 @@ class Honeypot(object):
                         server = StreamServer(('0.0.0.0', port), cap.handle_session)
 
                     logger.debug('Adding {0} capability with options: {1}'.format(cap_name, options))
-                    self.servers.append(server)
+                    self._servers.append(server)
                     server_greenlet = Greenlet(server.start())
-                    self.server_greenlets.append(server_greenlet)
+                    self._server_greenlets.append(server_greenlet)
 
                 except _socket.error as ex:
                     logger.error("Could not start {0} server on port {1}. Error: {2}".format(c.__name__, port, ex))
@@ -159,17 +165,17 @@ class Honeypot(object):
 
         logger.info("Honeypot running.")
 
-        gevent.joinall(self.server_greenlets)
+        gevent.joinall(self._server_greenlets)
 
     def stop(self):
         """Stops services"""
-        for s in self.servers:
+        for s in self._servers:
             s.stop()
 
-        for g in self.server_greenlets:
+        for g in self._server_greenlets:
             g.kill()
-
-        self.session_consumer.stop()
+        if self._session_consumer:
+            self._session_consumer.stop()
         logger.info('All workers stopped.')
 
     @staticmethod
@@ -187,14 +193,6 @@ class Honeypot(object):
         shutil.copytree(os.path.join(package_directory, 'drones/honeypot/data'), os.path.join(work_dir, 'data/'),
                         ignore=Honeypot._ignore_copy_files)
 
-        # this config file is for standalone operations, it will be overwritten during __init__
-        # if a config url is specified.
-        config_file = os.path.join(work_dir, 'beeswarmcfg.json.dist')
-        if not os.path.isfile('beeswarmcfg.json'):
-            logger.info('Copying configuration file to workdir.')
-            shutil.copyfile(os.path.join(package_directory, 'drones/honeypot/beeswarmcfg.json.dist'),
-                            os.path.join(work_dir, 'beeswarmcfg.json'))
-
     @staticmethod
     def _ignore_copy_files(path, content):
         to_ignore = []
